(* TextUtil.def provides simple text manipulation routines.

Copyright (C) 2023-2026 Free Software Foundation, Inc.
Contributed by Gaius Mulley <gaius.mulley@southwales.ac.uk>.

This file is part of GNU Modula-2.

GNU Modula-2 is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3, or (at your option)
any later version.

GNU Modula-2 is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

Under Section 7 of GPL version 3, you are granted additional
permissions described in the GCC Runtime Library Exception, version
3.1, as published by the Free Software Foundation.

You should have received a copy of the GNU General Public License and
a copy of the GCC Runtime Library Exception along with this program;
see the files COPYING3 and COPYING.RUNTIME respectively.  If not, see
<http://www.gnu.org/licenses/>.  *)

DEFINITION MODULE TextUtil ;

(*
    Title      : TextUtil
    Author     : Gaius Mulley
    System     : GNU Modula-2
    Date       : Tue May 16 18:22:44 2023
    Revision   : $Version$
    Description: provides text manmipulation routines.
*)

IMPORT IOChan ;


(*
   SkipSpaces - skips any spaces.
*)

PROCEDURE SkipSpaces (cid: IOChan.ChanId) ;


(* CharAvailable returns TRUE if IOChan.ReadResult is notKnown or
   allRight.  *)

PROCEDURE CharAvailable (cid: IOChan.ChanId) : BOOLEAN ;


(* EofOrEoln returns TRUE if IOChan.ReadResult is endOfLine or
   endOfInput.  *)

PROCEDURE EofOrEoln (cid: IOChan.ChanId) : BOOLEAN ;


END TextUtil.
